==================
Release Management
==================

Release management for Kolla Ansible is very much linked to that of Kolla. See
:kolla-doc:`Kolla release management <contributor/release-management.html>`.
